Package: cbcTools
Title: Design and Analyze Choice-Based Conjoint Experiments
Version: 0.7.1
Maintainer: John Helveston <john.helveston@gmail.com>
Authors@R: c(
    person(given   = "John",
           family  = "Helveston",
           role    = c("cre", "aut", "cph"),
           email   = "john.helveston@gmail.com",
           comment = c(ORCID = "0000-0002-2657-9191")))
Description: Design and evaluate choice-based conjoint survey experiments. Generate a variety of survey designs, including random designs, frequency-based designs, and D-optimal designs, as well as "labeled" designs (also known as "alternative-specific designs"), designs with "no choice" options, and designs with dominant alternatives removed. Conveniently inspect and compare designs using a variety of metrics, including design balance, overlap, and D-error, and simulate choice data for a survey design either randomly or according to a utility model defined by user-provided prior parameters. Conduct a power analysis for a given survey design by estimating the same model on different subsets of the data to simulate different sample sizes. Bayesian D-efficient designs using the 'cea' and 'modfed' methods are obtained using the 'idefix' package by Traets et al (2020) <doi:10.18637/jss.v096.i03>. Choice simulation and model estimation in power analyses are handled using the 'logitr' package by Helveston (2023) <doi:10.18637/jss.v105.i10>.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.2
VignetteBuilder: knitr
Depends: R (>= 3.5.0)
Suggests: here, knitr, testthat, tibble
Imports: fastDummies, ggplot2, idefix (>= 1.1.0), logitr (>= 1.0.1),
        parallel, randtoolbox, rlang, tools, stats, utils
URL: https://github.com/jhelvy/cbcTools,
        https://jhelvy.github.io/cbcTools/
BugReports: https://github.com/jhelvy/cbcTools/issues
NeedsCompilation: no
Packaged: 2025-10-20 19:22:34 UTC; jhelvy
Author: John Helveston [cre, aut, cph] (ORCID:
    <https://orcid.org/0000-0002-2657-9191>)
Repository: CRAN
Date/Publication: 2025-10-20 19:50:02 UTC
Built: R 4.6.0; ; 2026-04-29 13:32:39 UTC; unix
