# Generated by roxygen2: do not edit by hand

S3method("[",cbc_choices)
S3method("[",cbc_design)
S3method("[",cbc_profiles)
S3method("[<-",cbc_choices)
S3method("[<-",cbc_design)
S3method("[<-",cbc_profiles)
S3method("names<-",cbc_choices)
S3method("names<-",cbc_design)
S3method("names<-",cbc_profiles)
S3method(plot,cbc_power)
S3method(print,cbc_choices)
S3method(print,cbc_comparison)
S3method(print,cbc_design)
S3method(print,cbc_inspection)
S3method(print,cbc_power)
S3method(print,cbc_priors)
S3method(print,cbc_profiles)
S3method(summary,cbc_power)
export(cbc_choices)
export(cbc_compare)
export(cbc_decode)
export(cbc_design)
export(cbc_encode)
export(cbc_inspect)
export(cbc_power)
export(cbc_priors)
export(cbc_profiles)
export(cbc_restrict)
export(cor_spec)
export(int_spec)
export(plot_compare_power)
export(rand_spec)
